/*
 * console.h
 *
 * Copyright 2002, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */


#ifndef console_h
#define console_h


#include <sys/types.h>
#include <kern/debug.h>


#ifndef ASM_FILE


extern int registConsole();
extern int initConsole();
extern void initKeyboard();
extern int sendConsole(const uint);
extern int writeConsole(const char*, size_t);
extern int cnsoleSetTopProc();


#endif


#endif
